@@ -1,6 +1,6 @@
 package Pisg::HTMLGenerator;
 
-# $Id: HTMLGenerator.pm,v 1.186 2006/09/01 08:04:50 azoff Exp $
+# $Id: HTMLGenerator.pm,v 1.188 2006/12/30 21:50:19 azoff Exp $
 #
 # Copyright and license, as well as documentation(POD) for this module is
 # found at the end of the file.
@@ -217,7 +217,7 @@ sub _htmlheader
 
     my $CSS;
     if($self->{cfg}->{colorscheme} =~ /([^\/.]+)\.[^\/]+$/) { # use external CSS file
-        $CSS = "<link rel=\"stylesheet\" type=\"text/css\" title=\"$1\" href=\"$self->{cfg}->{colorscheme}\">";
+        $CSS = "<link rel=\"stylesheet\" type=\"text/css\" title=\"$1\" href=\"$self->{cfg}->{colorscheme}\" />";
     } elsif($self->{cfg}->{colorscheme} ne "none") { # read the chosen CSS file
         my $css_file = $self->{cfg}->{cssdir} . $self->{cfg}->{colorscheme} . ".css";
         open(FILE, $css_file) or open (FILE, $self->{cfg}->{search_path} . "/$css_file") or die("$0: Unable to open stylesheet $css_file: $!\n");
@@ -234,7 +234,7 @@ sub _htmlheader
     if($self->{cfg}->{altcolorscheme} ne "none" and $self->{cfg}->{altcolorscheme} =~ /[^\w]/) {
         foreach (split /\s+/, $self->{cfg}->{altcolorscheme}) {
             /([^\/.]+)\.[^\/]+$/;
-            $CSS .= "\n<link rel=\"alternate stylesheet\" type=\"text/css\" title=\"$1\" href=\"$_\">";
+            $CSS .= "\n<link rel=\"alternate stylesheet\" type=\"text/css\" title=\"$1\" href=\"$_\" />";
         }
     }
 
@@ -1769,7 +1769,7 @@ sub _mostusedword
 
     foreach my $word (keys %{ $self->{stats}->{wordcounts} }) {
         # Skip people's nicks.
-        next if is_nick($word);
+        next if is_nick($word, $self->{cfg}->{cachedir});
         next if (length($word) < $self->{cfg}->{wordlength});
         $usages{$word} = $self->{stats}->{wordcounts}{$word};
     }
@@ -2413,7 +2413,7 @@ sub _topactive {
         $self->{cfg}->{activenicks2} = $top_nicks-$self->{cfg}->{activenicks};
     }
             
-    (@top_active) = @top_active[0..($self->{cfg}->{activenicks}+$self->{cfg}->{activenicks2}-1)];
+    (@top_active) = @top_active[0..($self->{cfg}->{activenicks}-1)];
     $self->{stats}->{topactive_lines} = @top_active ? $self->{stats}->{lines}{$top_active[0]} : 1;
             
     foreach (@top_active) {
